==> ts-pfsense_1.04-01.tar.gz: ts-pfsense/tsgetblockip.php <==
 <?php
/**
 *
 * Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

//ini_set('display_errors',1);
//error_reporting(E_ALL);


require("filter.inc");
require("shaper.inc");
require_once("config.gui.inc");
require_once("/usr/local/www/threatstop.conf.php");

define('THREATSTOP_BLOCK', '169.254.0.0/16');

//logging current time
$log_handle = @fopen('/tmp/mydat', 'a');
fputs($log_handle, date("D M j G:i:s T Y", time()) . PHP_EOL);
fclose($log_handle);


//getting config values
$dnses = explode(' ', $DNSLIST);
$initial_blocklist = $BLOCKLIST ? $BLOCKLIST : '';
$initial_allowlist = $ALLOWLIST ? $ALLOWLIST : '';

if (strpos($initial_blocklist, '%') !== false || strpos($initial_allowlist, '%') !== false) {
    echo "Your configuration file has no appropriate blocklistname. Please check your command line installation instructions.";
    exit();
}

//Create
$block_filename = "/var/db/aliastables/ThreatSTOP_block.txt";
$allow_filename = "/var/db/aliastables/ThreatSTOP_allow.txt";

if (!file_exists('/var/db/aliastables')) {

    echo "Directory '/var/db/aliastables' does not exist. Creating...";
    @mkdir("/var/db/aliastables", 0755);
    if (file_exists('/var/db/aliastables')) {
        echo "Done\n";
    } else {
        echo "\n Operation failed. Probably you don't have permissions to create /var/db/aliastables. Exit.\n";
        exit();
    }
}

$f_blocklist = @fopen($block_filename, "w");
$f_allowlist = @fopen($allow_filename, "w");
//echo "HI################";

if (!f_blocklist || !f_allowlist) {

    echo "You can not create files, probably you do not have rights to do it. Creating block and allow lists aborted.";
    exit();

}
echo "\nGetting block and allow lists. Wait please...\n";

$dns_answered = false;

foreach ($dnses as $dns) {

        // Block list stuff
        $command = $NDIG . ' -t ptr @' . $dns . ' ' . $initial_blocklist;
        $response_ptr = `$command`;
        $response_strings = explode("\n", $response_ptr);

        foreach ($response_strings as $num => $string) {
            if (strpos($string, ';') === 0) {
                unset ($response_strings[$num]);
            }
        }
        $response_ptr = implode("\n", $response_strings);
        //echo "$response_ptr \n";
        if ($response_ptr) {

                $num_addresses = preg_match_all('#(.+\.)\n#', $response_ptr, $matches); //TODO preg_match

                foreach ($matches[1] as $address) {

                        $command = $NDIG . ' -t apl @' . $dns . ' ' . $address ;
                        $response_apl = shell_exec($command);

                        if ($response_apl) {

                                $ips_count = preg_match_all('#(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})\/(\d{2})#', $response_apl, $matches);

                                for ($i = 0; $i < count($matches[1]); $i++) {

                                        if (ip2long($matches[1][$i]) % pow(2,32 - ($matches[2][$i]))) {
                                            echo "Incorrect IP last digit for mask " . $matches[2][$i] . ' at ' . $matches[1][$i];
                                        } else {
                                                 fwrite ($f_blocklist, $matches[1][$i] . '/' . $matches[2][$i] . "\n");
                                        }

                                }
                        }
                }
                $dns_answered = true;
        }

        // Allow list stuff
        $command = $NDIG . ' -t ptr @' . $dns . ' ' . $initial_allowlist;
        $response_ptr = shell_exec($command);

        if ($response_ptr) {

                $num_addresses = preg_match_all('#(.+\.)\n#', $response_ptr, $matches); //TODO preg_match

                foreach ($matches[1] as $address) {

                        $command = $NDIG . ' -t apl @' . $dns . ' ' . $address ;
                        $response_apl = shell_exec($command);

                        if ($response_apl) {

                                $ips_count = preg_match_all('#(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})\/(\d{2})#', $response_apl, $matches);

                                for ($i = 0; $i < count($matches[1]); $i++) {

                                        if (ip2long($matches[1][$i]) % pow(2,32 - ($matches[2][$i]))) {
                                            echo "Incorrect IP last digit for mask " . $matches[2][$i] . ' at ' . $matches[1][$i];
                                        } else {
                                                 fwrite ($f_allowlist, $matches[1][$i] . '/' . $matches[2][$i] . "\n");
                                        }

                                }
                        }
                }
        }

	/*
	 * GS-905 : cannot keep reverting our anycast back to the old DNS list
	 * this ticket is about getting compatible with 2.3+, not implementing
	 * SRV at this time.  When SRV is implemented, lose the "false" below!
	 */
        if ( false && $dns_answered) {

            $command = $NDIG . ' -t apl dns.threatstop.local @' . $dns;
            $response_dns = `$command`;
            preg_match_all('#1:(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})/\d{1,2}#', $response_dns, $matches);
            $response_dns = $matches[1];

            $confFile = file_get_contents('/usr/local/www/threatstop.conf.php');
            $confStrings = explode(PHP_EOL, $confFile);
                foreach ($confStrings as $num => $confString) {

                    if (strpos($confString, '$DNSLIST') === 0) {
                        $confStrings[$num] = '$DNSLIST = \'' . implode(' ', $response_dns) . '\';';

                    }
                }
            file_put_contents('/usr/local/www/threatstop.conf.php', implode(PHP_EOL, $confStrings));
            break;
        }
}

 
if (!$dns_answered) {
        echo "No ThreatSTOP DNS servers are reachable \n";
        exit;
}

fclose($f_blocklist);
fclose($f_allowlist);


if (!filesize($allow_filename)) {

        file_put_contents ($allow_filename, implode("\n", $dnses) . PHP_EOL);

}

if (!filesize($block_filename)) {

        file_put_contents ($block_filename, THREATSTOP_BLOCK . PHP_EOL);

}

//echo $argv[1] ;
if (isset($argv[1]) && ($argv[1] == 'firewall')) {

    // If the file contains less than 5 strings, exit script
    $handle = @fopen($block_filename, "r");
    $linecount = 0;
    while (($linecount < 5) && ($line = fgets($handle))) {
        $linecount++;
    }
    fclose($handle);

    if ($linecount < 5) {
        exit;
    }

    //shell commands
    shell_exec('/sbin/pfctl -t ThreatSTOP_block -T replace -f ' . $block_filename);
    shell_exec('/sbin/pfctl -t ThreatSTOP_allow -T replace -f ' . $allow_filename);
}

?>

==> ts-pfsense_1.05-02.tar.gz: ts-pfsense/tsgetblockip.php <==
 <?php
/**
 *
 * Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

//ini_set('display_errors',1);
//error_reporting(E_ALL);


require("filter.inc");
require("shaper.inc");
require_once("config.gui.inc");
require_once("/usr/local/www/threatstop.conf.php");

function debug($msg) {
    if ($_SERVER['TSDEBUG'] == 1) {
        echo $msg;
    }
}

function records_filter($lines, $zone, $type) {
        $zone_escaped = str_replace(".", "\.", $zone);

        $elines = explode("\n", $lines);

        # Sneaky - drill adds space to the end of each line :/
        if ($type == "APL") {
             $regex = "/^$zone_escaped\.?\s+\d+\s+IN\s+$type\s+(\d:)?([a-z0-9\.:]+)(\/\d+)?\.?\s?$/i";
             foreach ($elines as $line) {
                 if (preg_match($regex, $line, $matches) === 1) {
                     //echo "MATCH $matches[2]$matches[3]\n";
                     $records = $records . "$matches[2]$matches[3]\n";
                 }
            }
        } elseif ($type == "PTR") {
             $regex = "/^$zone_escaped\.?\s+\d+\s+IN\s+$type\s+([a-z0-9\.\-]+)\.?\s?$/i";
             foreach ($elines as $line) {
                 if (preg_match($regex, $line, $matches) === 1) {
                     //echo "MATCH $matches[1]\n";
                     $records = $records . "$matches[1]\n";
                 }
            }
        } else {
             echo "Unexpected record type. Aborting.";
             exit(1);
        }
        return $records;
}

function dns_retr($zone, $type) {

   debug("RETRIEVE $zone (type $type)\n");

    if ($GLOBALS['TSDIG'] === "dig") {
        $cmd = $GLOBALS['NDIG'] . " @". $GLOBALS['DNSLIST'] ." +tcp -t $type $zone";
        $success_re = "/opcode: QUERY, status: NOERROR,.*QUERY: 1, ANSWER: (\d+)/s";

    } elseif ($GLOBALS['TSDIG'] == "drill") {
        $cmd = $GLOBALS['NDIG'] . " -t @". $GLOBALS['DNSLIST'] ." $type $zone";
        $success_re = "/opcode: QUERY, rcode: NOERROR,.*QUERY: 1, ANSWER: (\d+)/s";
    } else {
        echo "Unexpected DNS client configuration. Aborting.\n";
        exit(1);
    }

    $cwd='/tmp';
    $descriptorspec = array(
        0 => array("pipe", "r"),
        1 => array("pipe", "w"),
        2 => array("file", "/tmp/ts.log", "w") );

    debug("> $cmd\n");

    $process = proc_open($cmd, $descriptorspec, $pipes, $cwd);

    $response = trim(stream_get_contents($pipes[1]));
    fclose($pipes[1]);
    $rc = proc_close($process);

    if ($rc != 0 or
        preg_match($success_re, $response) == 0) {
        echo "Failed to retrieve policy [$cmd]\n";
        echo "Aborting.\n";
        exit(1);
    }
    $response = $response . "\n"; // for explode call
    return records_filter($response, $zone, $type);
}

define('THREATSTOP_BLOCK', '169.254.0.0/16');

//logging current time
$log_handle = @fopen('/tmp/mydat', 'a');
fputs($log_handle, date("D M j G:i:s T Y", time()) . PHP_EOL);
fclose($log_handle);


//getting config values
$dnses = explode(' ', $DNSLIST);
$initial_blocklist = $BLOCKLIST ? $BLOCKLIST : '';
$initial_allowlist = $ALLOWLIST ? $ALLOWLIST : '';

if (strpos($initial_blocklist, '%') !== false || strpos($initial_allowlist, '%') !== false) {
    echo "Your configuration file has no appropriate blocklistname. Please check your command line installation instructions.";
    exit();
}

//Create
$block_filename = "/var/db/aliastables/ThreatSTOP_block.txt";
$allow_filename = "/var/db/aliastables/ThreatSTOP_allow.txt";

if (!file_exists('/var/db/aliastables')) {

    echo "Directory '/var/db/aliastables' does not exist. Creating...";
    @mkdir("/var/db/aliastables", 0755);
    if (file_exists('/var/db/aliastables')) {
        echo "Done\n";
    } else {
        echo "\n Operation failed. Probably you don't have permissions to create /var/db/aliastables. Exit.\n";
        exit();
    }
}

$f_blocklist = @fopen($block_filename, "w");
$f_allowlist = @fopen($allow_filename, "w");

if (!f_blocklist || !f_allowlist) {

    echo "You can not create files, probably you do not have rights to do it. Creating block and allow lists aborted.";
    exit();

}
echo "\nGetting block and allow lists. Wait please...\n";

$dns_answered = false;

foreach ($dnses as $dns) {

        // Block list
        $response_ptr = dns_retr($initial_blocklist, "PTR");
        if ($response_ptr) {

                $num_addresses = preg_match_all('#(.+\.)\n#', $response_ptr, $matches); //TODO preg_match

                foreach ($matches[1] as $address) {

                        $response_apl = dns_retr($address, 'APL');

                        if ($response_apl) {

                                $ips_count = preg_match_all('#(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})\/(\d{2})#', $response_apl, $matches);

                                for ($i = 0; $i < count($matches[1]); $i++) {

                                        if (ip2long($matches[1][$i]) % pow(2,32 - ($matches[2][$i]))) {
                                            echo "Incorrect IP last digit for mask " . $matches[2][$i] . ' at ' . $matches[1][$i];
                                        } else {
                                                 fwrite ($f_blocklist, $matches[1][$i] . '/' . $matches[2][$i] . "\n");
                                        }

                                }
                        }
                }
                $dns_answered = true;
        }

        // Allow list
        $response_ptr = dns_retr($initial_allowlist, "PTR");
        $response_strings = explode("\n", $response_ptr);

        if ($response_ptr) {

                $num_addresses = preg_match_all('#(.+\.)\n#', $response_ptr, $matches); //TODO preg_match

                foreach ($matches[1] as $address) {

                        $response_apl = dns_retr($address, 'APL');

                        if ($response_apl) {

                                $ips_count = preg_match_all('#(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})\/(\d{2})#', $response_apl, $matches);

                                for ($i = 0; $i < count($matches[1]); $i++) {

                                        if (ip2long($matches[1][$i]) % pow(2,32 - ($matches[2][$i]))) {
                                            echo "Incorrect IP last digit for mask " . $matches[2][$i] . ' at ' . $matches[1][$i];
                                        } else {
                                                 fwrite ($f_allowlist, $matches[1][$i] . '/' . $matches[2][$i] . "\n");
                                        }

                                }
                        }
                }
        }

	/*
	 * GS-905 : cannot keep reverting our anycast back to the old DNS list
	 * this ticket is about getting compatible with 2.3+, not implementing
	 * SRV at this time.  When SRV is implemented, lose the "false" below!
	 */
        if ( false && $dns_answered) {

            $response_apl = dns_retr("dns.threatstop.local", 'APL');

            preg_match_all('#1:(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})/\d{1,2}#', $response_dns, $matches);
            $response_dns = $matches[1];

            $confFile = file_get_contents('/usr/local/www/threatstop.conf.php');
            $confStrings = explode(PHP_EOL, $confFile);
                foreach ($confStrings as $num => $confString) {

                    if (strpos($confString, '$DNSLIST') === 0) {
                        $confStrings[$num] = '$DNSLIST = \'' . implode(' ', $response_dns) . '\';';

                    }
                }
            file_put_contents('/usr/local/www/threatstop.conf.php', implode(PHP_EOL, $confStrings));
            break;
        }
}

 
if (!$dns_answered) {
        echo "No ThreatSTOP DNS servers are reachable \n";
        exit;
}

fclose($f_blocklist);
fclose($f_allowlist);


if (!filesize($allow_filename)) {

        file_put_contents ($allow_filename, implode("\n", $dnses) . PHP_EOL);

}

if (!filesize($block_filename)) {

        file_put_contents ($block_filename, THREATSTOP_BLOCK . PHP_EOL);

}

//echo $argv[1] ;
if (isset($argv[1]) && ($argv[1] == 'firewall')) {

    // If the file contains less than 5 strings, exit script
    $handle = @fopen($block_filename, "r");
    $linecount = 0;
    while (($linecount < 5) && ($line = fgets($handle))) {
        $linecount++;
    }
    fclose($handle);

    if ($linecount < 5) {
        exit;
    }

    //shell commands
    shell_exec('/sbin/pfctl -t ThreatSTOP_block -T replace -f ' . $block_filename);
    shell_exec('/sbin/pfctl -t ThreatSTOP_allow -T replace -f ' . $allow_filename);
}

?>
